@@ -17,7 +17,7 @@ case $DESKTOP_CODE in
             FM=`cat $SESSION_FILE |grep "^Default-FM=" |cut -d "=" -f2` &&
             exec "$FM" &
         else
-            FM="rox-filer" &&
+            FM="zzzfmr" &&
             touch $SESSION_FILE &&
             echo "#This is where the menu, toolbar, and control center file manager should be set" > $SESSION_FILE &&
             echo "Default-FM=$FM" >> $SESSION_FILE &&
